#
# $Id: vmprov-i18n.sh,v 3.4.1.10 2005/05/11 13:09:56 joe Exp $
#
# Copyright  2005 VERITAS Software Corporation. All Rights Reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND
# TRADE SECRETS OF VERITAS SOFTWARE.  USE, DISCLOSURE,
# OR REPRODUCTION IS PROHIBITED WITHOUT THE PRIOR
# EXPRESS WRITTEN PERMISSION OF VERITAS SOFTWARE CORPORATION
#
#               RESTRICTED RIGHTS LEGEND
# USE, DUPLICATION OR DISCLOSURE BY THE U.S. GOVERNMENT IS
# SUBJECT TO RESTRICTIONS SET FORTH IN
# THE VERITAS SOFTWARE CORPORATION LICENSE AGREEMENT AND AS
# PROVIDED IN DFARS 227.7202-1(a) and
# 227.7202-3(a) (1998), and FAR 12.212, as applicable.
# VERITAS Software Corporation
# 350 Ellis Street,
# Mountain View, CA 94043.
#
# UNPUBLISHED -- RIGHTS RESERVED UNDER THE COPYRIGHT
# LAWS OF THE UNITED STATES.  USE OF A COPYRIGHT NOTICE
# IS PRECAUTIONARY ONLY AND DOES NOT IMPLY PUBLICATION
# OR DISCLOSURE.
#
# vmprov.sh manual install/remove VM Provider script 
#
######################################################################
# globals for VRTSob package and VRTSvmpro package
######################################################################
OS_PLAT=`uname -s`
PKGNAME=VRTSmuvmp

if [ -z "$BASEDIR" -o "$OS_PLAT" = "AIX" ]
then
	BASEDIR=/opt
fi
OBDIR=$BASEDIR/VRTSob
VMPRODIR=$BASEDIR/VRTSvmpro

VMPROBASE=/opt/VRTSvmpro
OBBASE=/opt/VRTSob

LD_LIBRARY_PATH=$OBDIR/lib:$LD_LIBRARY_PATH
export LD_LIBRARY_PATH

LANG=C; export LANG
LC_ALL=C; export LC_ALL
LC_CTYPE=C; export LC_CTYPE
LC_MESSAGES=C; export LC_MESSAGES

message()
{
	$_ECHO "$@"
}

errmsg()
{
	$_ECHO "ERROR:   $@"
}

warning()
{
	$_ECHO "WARNING: $@"
}


note()
{
	$_ECHO "NOTE:    $@"
}


fatalexit()
{
	[ "$verbose" = "yes" ] && \
	     message "          Please fix the problem and re-run this script.\n"
	exit 1
}

usage()
{
	if [ "$prt_usage" = "yes" ]
	then
		message "Usage:  vmprov.sh [-f|v|p] { add | remove }\n"
		exit 1
	fi
}


getguid()
{
	SYMBOL=$1
	FILE=$2

	while read  guid
	do
		NAME=`$REGOPS $REGFILE queryvalue "$GPATH/$guid" SymbolicName 2>/dev/null | cut -c27-`
		if [ "$NAME" = "$SYMBOL" ] 
		then
			echo $guid
			return 0
		fi
	done < $FILE
	return 1
}


incr_version()
{
		integer_part=`echo $1|cut -f 1,3 -d .`
		decimal_part=`echo $1|sed -e "s/$integer_part\.//"`
		up_decimal_part=`expr $decimal_part + 1`
		echo "$integer_part.$up_decimal_part"
}

decr_version()
{
		integer_part=`echo $1|cut -f 1,3 -d .`
		decimal_part=`echo $1|sed -e "s/$integer_part\.//"`

		if [ $decimal_part != "0" ]
		then
			down_decimal_part=`expr $decimal_part - 1`
		else
			down_decimal_part=$decimal_part
		fi

		echo "$integer_part.$down_decimal_part"
}




##############################################################################
# function to register the vmprovider to VIP                                 #
##############################################################################

vmprov_register()
{
    if [ ! -f $VMPRODIR/lib/vxvmprovider.$SHLIB_EXT ]
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && errmsg "VM provider installation terminated; this VM provider package does not
         contain a VM provider library for this version of VM.\n"
	fatalexit
    fi

    #############################################
    # VERITAS Enterprise Administrator Service registry file paramaters
    #############################################

    if [ ! -x $REGOPS  -o ! -f $REGFILE ] 
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && errmsg "Cannot locate the VERITAS Enterprise Administrator Service utilities.  
         Please fix this problem and then reattempt this configuration removal.
 
         Aborting VM provider configuration installation attempt."
	exit 3
    fi


    [ "$verbose" = "yes" ] && note "Adding VM provider Localized Resource files to Enterprise Administrator Service registry file...\c"
    cp $REGFILE $REGFILE.pre-vmpro


    [ "$verbose" = "yes" ] && message ""

# French

    [ ! -d $OBDIR/extensions/VxSearch/IsisSkin/java/1036 ] && \
    	mkdir -p $OBDIR/extensions/VxSearch/IsisSkin/java/1036 2>/dev/null
    cp $VMPRODIR/extensions/SearchResourceBundle.fr.jar \
	    $OBDIR/extensions/VxSearch/IsisSkin/java/1036/SearchResourceBundle.fr.jar

    $REGOPS $REGFILE createkey $GUIKEY_SearchResourceBundle_fr
    $REGOPS $REGFILE setvalue $GUIKEY_SearchResourceBundle_fr ImageFile REG_SZ $OBBASE/extensions/VxSearch/IsisSkin/java/1036/SearchResourceBundle.fr.jar 


    $REGOPS $REGFILE setvalue $GUIKEY_SearchResourceBundle_fr Version REG_SZ $SearchResourceBundle_fr_VERSION


    $REGOPS $REGFILE createkey $GUIKEY_VmResourceBundle_fr
    $REGOPS $REGFILE setvalue $GUIKEY_VmResourceBundle_fr ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VmResourceBundle.fr.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VmResourceBundle_fr Version REG_SZ $VmResourceBundle_fr_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VmLibResourceBundle_fr
    $REGOPS $REGFILE setvalue $GUIKEY_VmLibResourceBundle_fr ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VmLibResourceBundle.fr.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VmLibResourceBundle_fr Version REG_SZ $VmLibResourceBundle_fr_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmOneguiResourceBundle_fr
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmOneguiResourceBundle_fr ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VxVmOneguiResourceBundle.fr.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmOneguiResourceBundle_fr Version REG_SZ $VxVmOneguiResourceBundle_fr_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmVxFsResourceBundle_fr
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmVxFsResourceBundle_fr ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VxVmVxFsResourceBundle.fr.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmVxFsResourceBundle_fr Version REG_SZ $VxVmVxFsResourceBundle_fr_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmHelp_fr
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmHelp_fr ImageFile REG_SZ $CLIENT_EXT_VXVM/VxVmHelp.fr.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmHelp_fr Version REG_SZ $VxVmHelp_fr_VERSION


    $REGOPS $REGFILE setvalue $KEY MessageCatalog REG_SZ {$VMMSGGUID}
    $REGOPS $REGFILE createkey $VMMSGKEY_fr
    $REGOPS $REGFILE setvalue $VMMSGKEY_fr ImageFile REG_SZ $VMPROBASE/msgcats/vxvmprovider.fr.cat
    $REGOPS $REGFILE setvalue $VMMSGKEY_fr Version REG_SZ $VMMSGGUID_VERSION


# Japanese
    [ ! -d $OBDIR/extensions/VxSearch/IsisSkin/java/1041 ] && \
    	mkdir -p $OBDIR/extensions/VxSearch/IsisSkin/java/1041 2>/dev/null

    cp $VMPRODIR/extensions/SearchResourceBundle.ja.jar \
	    $OBDIR/extensions/VxSearch/IsisSkin/java/1041/SearchResourceBundle.ja.jar

    $REGOPS $REGFILE createkey $GUIKEY_SearchResourceBundle_ja
    $REGOPS $REGFILE setvalue $GUIKEY_SearchResourceBundle_ja ImageFile REG_SZ $OBBASE/extensions/VxSearch/IsisSkin/java/1041/SearchResourceBundle.ja.jar 
    $REGOPS $REGFILE setvalue $GUIKEY_SearchResourceBundle_ja Version REG_SZ $SearchResourceBundle_ja_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VmResourceBundle_ja
    $REGOPS $REGFILE setvalue $GUIKEY_VmResourceBundle_ja ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VmResourceBundle.ja.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VmResourceBundle_ja Version REG_SZ $VmResourceBundle_ja_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VmLibResourceBundle_ja
    $REGOPS $REGFILE setvalue $GUIKEY_VmLibResourceBundle_ja ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VmLibResourceBundle.ja.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VmLibResourceBundle_ja Version REG_SZ $VmLibResourceBundle_ja_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmOneguiResourceBundle_ja
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmOneguiResourceBundle_ja ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VxVmOneguiResourceBundle.ja.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmOneguiResourceBundle_ja Version REG_SZ $VxVmOneguiResourceBundle_ja_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmVxFsResourceBundle_ja
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmVxFsResourceBundle_ja ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VxVmVxFsResourceBundle.ja.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmVxFsResourceBundle_ja Version REG_SZ $VxVmVxFsResourceBundle_ja_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmHelp_ja
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmHelp_ja ImageFile REG_SZ $CLIENT_EXT_VXVM/VxVmHelp.ja.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmHelp_ja Version REG_SZ $VxVmHelp_ja_VERSION

    $REGOPS $REGFILE setvalue $KEY MessageCatalog REG_SZ {$VMMSGGUID}
    $REGOPS $REGFILE createkey $VMMSGKEY_ja
    $REGOPS $REGFILE setvalue $VMMSGKEY_ja ImageFile REG_SZ $VMPROBASE/msgcats/vxvmprovider.ja.cat
    $REGOPS $REGFILE setvalue $VMMSGKEY_ja Version REG_SZ $VMMSGGUID_VERSION



# Chinese
    [ ! -d $OBDIR/extensions/VxSearch/IsisSkin/java/4 ] && \
    	mkdir -p $OBDIR/extensions/VxSearch/IsisSkin/java/4 2>/dev/null
    cp $VMPRODIR/extensions/SearchResourceBundle.zh.jar \
	    $OBDIR/extensions/VxSearch/IsisSkin/java/4/SearchResourceBundle.zh.jar

    $REGOPS $REGFILE createkey $GUIKEY_SearchResourceBundle_zh
    $REGOPS $REGFILE setvalue $GUIKEY_SearchResourceBundle_zh ImageFile REG_SZ $OBBASE/extensions/VxSearch/IsisSkin/java/4/SearchResourceBundle.zh.jar 
    $REGOPS $REGFILE setvalue $GUIKEY_SearchResourceBundle_zh Version REG_SZ $SearchResourceBundle_zh_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VmResourceBundle_zh
    $REGOPS $REGFILE setvalue $GUIKEY_VmResourceBundle_zh ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VmResourceBundle.zh.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VmResourceBundle_zh Version REG_SZ $VmResourceBundle_zh_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VmLibResourceBundle_zh
    $REGOPS $REGFILE setvalue $GUIKEY_VmLibResourceBundle_zh ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VmLibResourceBundle.zh.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VmLibResourceBundle_zh Version REG_SZ $VmLibResourceBundle_zh_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmOneguiResourceBundle_zh
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmOneguiResourceBundle_zh ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VxVmOneguiResourceBundle.zh.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmOneguiResourceBundle_zh Version REG_SZ $VxVmOneguiResourceBundle_zh_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmVxFsResourceBundle_zh
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmVxFsResourceBundle_zh ImageFile REG_SZ $CLIENT_EXT_RESOURCE/VxVmVxFsResourceBundle.zh.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmVxFsResourceBundle_zh Version REG_SZ $VxVmVxFsResourceBundle_zh_VERSION

    $REGOPS $REGFILE createkey $GUIKEY_VxVmHelp_zh
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmHelp_zh ImageFile REG_SZ $CLIENT_EXT_VXVM/VxVmHelp.zh.jar
    $REGOPS $REGFILE setvalue $GUIKEY_VxVmHelp_zh Version REG_SZ $VxVmHelp_zh_VERSION

    $REGOPS $REGFILE setvalue $KEY MessageCatalog REG_SZ {$VMMSGGUID}
    $REGOPS $REGFILE createkey $VMMSGKEY_zh
    $REGOPS $REGFILE setvalue $VMMSGKEY_zh ImageFile REG_SZ $VMPROBASE/msgcats/vxvmprovider.zh.cat
    $REGOPS $REGFILE setvalue $VMMSGKEY_zh Version REG_SZ $VMMSGGUID_VERSION


}


vmprov_unregister()
{
    #
    # update Enterprise Administrator Service Registry file to remove 
    # VM provider configuration info.
    #

    if [ ! -x $REGOPS -o  ! -f $REGFILE ] 
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && errmsg "Cannot locate the VERITAS Enterprise Administrator Service utilities.  
         Please fix this problem and then reattempt this configuration removal.
 
         Aborting VM provider configuration installation attempt."
	exit 3
    fi

# delete localized vmprovider.*.cat message files

    $REGOPS $REGFILE deletevalue $KEY MessageCatalog
    $REGOPS $REGFILE deletekeyrecursive $VMMSGKEY

    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_SearchResourceBundle_fr
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_SearchResourceBundle_ja
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_SearchResourceBundle_zh

    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmHelp_fr
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmHelp_ja
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmHelp_zh

    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VmResourceBundle_fr
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VmResourceBundle_ja
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VmResourceBundle_zh

    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VmLibResourceBundle_fr
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VmLibResourceBundle_ja
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VmLibResourceBundle_zh

    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmOneguiResourceBundle_fr
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmOneguiResourceBundle_ja
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmOneguiResourceBundle_zh

    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmVxFsResourceBundle_fr
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmVxFsResourceBundle_ja
    $REGOPS $REGFILE deletekeyrecursive $GUIKEY_VxVmVxFsResourceBundle_zh

}


###############################################
# function to patchadd the vm locatization pkg
###############################################
vmprov_patchadd()
{
    if [ ! -f $VMPRODIR/lib/vxvmprovider.$SHLIB_EXT ]
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && errmsg "VM provider patchadd terminated; this VM provider package does not
         contain a VM provider library for this version of VM.\n"
	fatalexit
    fi

    if [ ! -x $REGOPS  -o ! -f $REGFILE ] 
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && errmsg "Cannot locate the VERITAS Enterprise Administrator Service utilities.  
         Please fix this problem and then reattempt this configuration removal.
 
         Aborting VM provider patchadd attempt."
	exit 3
    fi


    [ "$verbose" = "yes" ] && \
		note "Adding VM provider Localized Resources patch in VEA Registry ... \c"

    cp $REGFILE $REGFILE.pre-vmpro

    $REGOPS $REGFILE enumkey $KEYC >$TMPFILE

    ######################
    # Increment versions of the client extension entries
    ######################
    #

    #### fr VxVM Help
    SKIN=IsisSkin/1/1036
    guid=`getguid VxVmHelp $TMPFILE`
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    #### ja VxVM Help
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr


    #### zh VxVM Help
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    ##

    # fr VmResourceBundle
    guid=`getguid VmResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # ja VmResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # zh VmResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

###
    # fr VmLibResourceBundle
    guid=`getguid VmLibResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # ja VmLibResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # zh VmLibResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

###
    # fr VxVmOneguiResourceBundle
    guid=`getguid VxVmOneguiResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # ja VxVmOneguiResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # zh VxVmOneguiResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

###
###
    # fr VxVmVxFsResourceBundle
    guid=`getguid VxVmVxFsResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # ja VxVmVxFsResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    # zh VxVmVxFsResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    ##

    #### fr Search Resource Bundles
    SKIN=IsisSkin/1/1036
    guid=`getguid SearchResourceBundle $TMPFILE`
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    #### ja Search Resource Bundles
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    #### zh Search Resource Bundles
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $incr

    ##

    #### fr Message Catalogs

    guid=$VMMSGGUID

    ver=`$REGOPS $REGFILE queryvalue $VMMSGKEY/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $VMMSGKEY_fr Version REG_SZ $incr

    #### ja Message Catalogs
    ver=`$REGOPS $REGFILE queryvalue $VMMSGKEY/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $VMMSGKEY_ja Version REG_SZ $incr

    #### zh Message Catalogs
    ver=`$REGOPS $REGFILE queryvalue $VMMSGKEY/$SKIN Version 2>/dev/null | awk '{print $5}'`
    incr=`incr_version $ver`
    $REGOPS $REGFILE setvalue $VMMSGKEY_zh Version REG_SZ $incr

    echo
}

###############################################
# function to patch rm the vm provider to VEA #
###############################################

vmprov_patchrm()
{
    if [ ! -x $REGOPS -o ! -f $REGFILE ] 
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && warning "Cannot locate the VERITAS Enterprise Administrator Service utilities to remove Registry entries."
	# allow uninstall to continue
	exit 0
    fi


    [ "$verbose" = "yes" ] && \
		note "Removing VRTSmuvmp patch from VEA Registry ... \c"

    cp $REGFILE $REGFILE.pre-vmpro

    $REGOPS $REGFILE enumkey $KEYC >$TMPFILE
    SKIN=IsisSkin/1/1033

    ######################
    # decrement versions of the client extension entries
    ######################


    #### fr VxVM Help
    SKIN=IsisSkin/1/1036
    guid=`getguid VxVmHelp $TMPFILE`
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    #### ja VxVM Help
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr


    #### zh VxVM Help
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    ##

    # fr VmResourceBundle
    guid=`getguid VmResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # ja VmResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # zh VmResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

###
    # fr VmLibResourceBundle
    guid=`getguid VmLibResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # ja VmLibResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # zh VmLibResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

###
    # fr VxVmOneguiResourceBundle
    guid=`getguid VxVmOneguiResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # ja VxVmOneguiResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # zh VxVmOneguiResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

###
    # fr VxVmVxFsResourceBundle
    guid=`getguid VxVmVxFsResourceBundle $TMPFILE`
    SKIN=IsisSkin/1/1036
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # ja VxVmVxFsResourceBundle
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    # zh VxVmVxFsResourceBundle
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    ##


    #### fr Search Resource Bundles
    SKIN=IsisSkin/1/1036
    guid=`getguid SearchResourceBundle $TMPFILE`
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    #### ja Search Resource Bundles
    SKIN=IsisSkin/1/1041
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr

    #### zh Search Resource Bundles
    SKIN=IsisSkin/1/4
    ver=`$REGOPS $REGFILE queryvalue $KEYC/$guid/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $KEYC/$guid/$SKIN Version REG_SZ $decr


    #### fr Message Catalogs
    guid=$VMMSGGUID
    ver=`$REGOPS $REGFILE queryvalue $VMMSGKEY/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $VMMSGKEY_fr Version REG_SZ $decr

    #### ja Message Catalogs
    ver=`$REGOPS $REGFILE queryvalue $VMMSGKEY/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $VMMSGKEY_ja Version REG_SZ $decr


    #### zh Message Catalogs
    ver=`$REGOPS $REGFILE queryvalue $VMMSGKEY/$SKIN Version 2>/dev/null | awk '{print $5}'`
    decr=`decr_version $ver`
    $REGOPS $REGFILE setvalue $VMMSGKEY_zh Version REG_SZ $decr

    echo
}


set_echo()
{
	case $OS_PLAT in
	SunOS | Solaris)
		_ECHO="echo"	
		;;		
	AIX | aix)
		_ECHO="echo"	
		;;		
	HP-UX | hpux)
		_ECHO="echo"	
		;;		
	Linux | linux)
		_ECHO="echo -e"	
		;;		
	esac	
}


###########################################################################
###  main()
###########################################################################
force=no
verbose=no
debug=no
prt_usage=yes
prt_error_only=yes
_ECHO="echo"

set_echo

if [ $# -lt 1 ]
then
	usage
	exit 1
fi

while getopts :fFvVdDpPqQeE c
do
        case $c in
        f|F)    force=yes	
		;;
        v|V)    verbose=yes
		;;
        d|D)    debug=yes
		;;
        p|P)    prt_usage=no; verbose=yes; prt_error_only=yes 
		;;
        q|E)    prt_usage=no; verbose=no; prt_error_only=no 
		;;
        e|E)    prt_usage=no; verbose=no; prt_error_only=yes 
		;;
        ?)      usage; exit 1           
		;;
        esac
done

shift `expr $OPTIND - 1`
if [ $# -ne 1 ]
then
	usage  
	exit 1
fi

option=$1
if [ -z "$option" ]
then
	usage
	exit 1
fi

case $option in
	add)		action=add	;;
	remove)		action=remove	;;
	patchadd) 	action=patchadd	;;
	patchrm) 	action=patchrm	;;

*)      usage; exit 1	;;
esac


    TMPFILE=/tmp/_vmpro_guids_
    REGOPS=$OBDIR/bin/vxregctl
    REGFILE=$PKG_INSTALL_ROOT/etc/vx/isis/Registry
    KEY=Software/VERITAS/VxSvc/CurrentVersion/Providers/vxvmprovider
    SKEY=Software/VERITAS/VxSvc/CurrentVersion/Providers/searchprovider
    KEYC=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions

# msgcat guid
    VMMSGGUID="616cb51c-1dd2-11b2-9623-0800209ead9c"
    VMMSGGUID_VERSION="1.0"
    VMMSGKEY=Software/VERITAS/VxSvc/CurrentVersion/MessageCatalogs/{$VMMSGGUID}
    VMMSGKEY_fr=Software/VERITAS/VxSvc/CurrentVersion/MessageCatalogs/{$VMMSGGUID}/IsisSkin/1/1036
    VMMSGKEY_ja=Software/VERITAS/VxSvc/CurrentVersion/MessageCatalogs/{$VMMSGGUID}/IsisSkin/1/1041
    VMMSGKEY_zh=Software/VERITAS/VxSvc/CurrentVersion/MessageCatalogs/{$VMMSGGUID}/IsisSkin/1/4


    if [ ! -x $REGOPS -o ! -f $REGFILE ] 
    then
	[ "$verbose" = "yes" -o "$prt_error_only" = "yes" ] && errmsg "Cannot locate the VERITAS Enterprise Administrator Service utilities.  
         Please fix this problem and then reattempt this configuration removal.
 
         Aborting VM provider Localized Resource configuration attempt."
	exit 3
    fi


###################################
#
#  client extension GUID
#
###################################

#
VxSearchCE_VERSION="1.5"
SearchResourceBundle_fr_VERSION="1.5"
SearchResourceBundle_ja_VERSION="1.5"
SearchResourceBundle_zh_VERSION="1.5"
CLIENT_EXT_VxSearchCE="27312042-1dd2-11b2-840a-080020a6bb38"
CLIENT_EXT_SearchResourceBundle="eba32058-1dd1-11b2-840b-080020a6bb38"
#
VxVmHelp_fr_VERSION="1.1"
VmResourceBundle_fr_VERSION="1.1"
VmLibResourceBundle_fr_VERSION="1.1"
VxVmOneguiResourceBundle_fr_VERSION="1.1"
VxVmVxFsResourceBundle_fr_VERSION="1.1"
#
VxVmHelp_ja_VERSION="1.1"
VmResourceBundle_ja_VERSION="1.1"
VmLibResourceBundle_ja_VERSION="1.1"
VxVmOneguiResourceBundle_ja_VERSION="1.1"
VxVmVxFsResourceBundle_ja_VERSION="1.1"
#
VxVmHelp_zh_VERSION="1.1"
VmResourceBundle_zh_VERSION="1.1"
VmLibResourceBundle_zh_VERSION="1.1"
VxVmOneguiResourceBundle_zh_VERSION="1.1"
VxVmVxFsResourceBundle_zh_VERSION="1.1"

#
#
# lookup
VxVmHelp_en_VERSION="1.1"
VmResourceBundle_en_VERSION="1.1"
VmLibResourceBundle_en_VERSION="1.1"
VxVmOneguiResourceBundle_en_VERSION="1.1"
#
CLIENT_EXT_VxVmHelp="df2b509c-1dd1-11b2-840a-080020a6bb38"
CLIENT_EXT_VmResourceBundle="df60379e-1dd1-11b2-840a-080020a6bb38"
CLIENT_EXT_VmLibResourceBundle="df9106a8-1dd1-11b2-840a-080020a6bb38"
CLIENT_EXT_VxVmOneguiResourceBundle="dfb260d2-1dd1-11b2-840a-080020a6bb38"
CLIENT_EXT_VxVmVxFsResourceBundle="dfeb2c96-1dd1-11b2-840a-080020a6bb38"

#%NEW_GUIDS

##########################################
# lookup guids from current Registry and set guids accordingly
#
GPATH=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions
$REGOPS $REGFILE enumkey $GPATH >$TMPFILE
#
guid=`getguid VxVmHelp $TMPFILE | sed 's/{//g' | sed 's/}//g'`
if [ $? = 0 ]
then
	CLIENT_EXT_VxVmHelp=$guid 
fi

guid=`getguid VmResourceBundle $TMPFILE | sed 's/{//g' | sed 's/}//g'`
if [ $? = 0 ]
then
	CLIENT_EXT_VmResourceBundle=$guid 
fi


guid=`getguid VmLibResourceBundle $TMPFILE | sed 's/{//g' | sed 's/}//g'`
if [ $? = 0 ]
then
	CLIENT_EXT_VmLibResourceBundle=$guid 
fi


guid=`getguid VxVmOneguiResourceBundle $TMPFILE | sed 's/{//g' | sed 's/}//g'`
if [ $? = 0 ]
then
	CLIENT_EXT_VxVmOneguiResourceBundle=$guid 
fi


guid=`getguid VxVmVxFsResourceBundle $TMPFILE | sed 's/{//g' | sed 's/}//g'`
if [ $? = 0 ]
then
	CLIENT_EXT_VxVmVxFsResourceBundle=$guid 
fi

guid=`getguid SearchResourceBundle $TMPFILE | sed 's/{//g' | sed 's/}//g'`
if [ $? = 0 ]
then
	CLIENT_EXT_SearchResourceBundle=$guid 
fi
##########################################


    #############################
    # client extension paramaters
    #############################
    CLIENT_EXT_VXVM=$VMPROBASE/extensions
    CLIENT_EXT_RESOURCE=$VMPROBASE/extensions
    #
    GUIKEY=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions
    GUIKEY_SearchResourceBundle_fr=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_SearchResourceBundle}/IsisSkin/1/1036
    GUIKEY_SearchResourceBundle_ja=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_SearchResourceBundle}/IsisSkin/1/1041
    GUIKEY_SearchResourceBundle_zh=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_SearchResourceBundle}/IsisSkin/1/4



    #### VxVmHelp
    GUIKEY_VxVmHelp_fr=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmHelp}/IsisSkin/1/1036
    GUIKEY_VxVmHelp_ja=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmHelp}/IsisSkin/1/1041
    GUIKEY_VxVmHelp_zh=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmHelp}/IsisSkin/1/4
    #
    #### VmResourceBundle
    GUIKEY_VmResourceBundle_fr=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VmResourceBundle}/IsisSkin/1/1036
    GUIKEY_VmResourceBundle_ja=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VmResourceBundle}/IsisSkin/1/1041
    GUIKEY_VmResourceBundle_zh=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VmResourceBundle}/IsisSkin/1/4
    #	
    #### VmLibResourceBundle
    GUIKEY_VmLibResourceBundle_fr=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VmLibResourceBundle}/IsisSkin/1/1036
    GUIKEY_VmLibResourceBundle_ja=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VmLibResourceBundle}/IsisSkin/1/1041
    GUIKEY_VmLibResourceBundle_zh=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VmLibResourceBundle}/IsisSkin/1/4
    #
    #### VxVmOneguiResourceBundle
    GUIKEY_VxVmOneguiResourceBundle_fr=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmOneguiResourceBundle}/IsisSkin/1/1036
    GUIKEY_VxVmOneguiResourceBundle_ja=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmOneguiResourceBundle}/IsisSkin/1/1041
    GUIKEY_VxVmOneguiResourceBundle_zh=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmOneguiResourceBundle}/IsisSkin/1/4
    #
    #### VxVmVxFsResourceBundle
    GUIKEY_VxVmVxFsResourceBundle_fr=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmVxFsResourceBundle}/IsisSkin/1/1036
    GUIKEY_VxVmVxFsResourceBundle_ja=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmVxFsResourceBundle}/IsisSkin/1/1041
    GUIKEY_VxVmVxFsResourceBundle_zh=Software/VERITAS/VxSvc/CurrentVersion/ClientExtensions/{$CLIENT_EXT_VxVmVxFsResourceBundle}/IsisSkin/1/4


###################################
#
# add VM provider config
#
###################################
    set_echo	
    if [ "$force" = "no" ]
    then
	OS_PLAT=`uname -s`
    	case $OS_PLAT in
    	SunOS | Solaris)
	    SHLIB_EXT=so
	    ### test for "if pkginfo -q VRTSob" or "if pkginfo -q VRTSobdev"
	    OBPKG=0
	    OBDEVPKG=0

	    if [ -n "$PKG_INSTALL_ROOT" ]; then
                PKGINFO="pkginfo -R $PKG_INSTALL_ROOT"
            else
                PKGINFO="pkginfo"
            fi

	    $PKGINFO -q VRTSob > /dev/null 2>&1
	    if [ $? = 0 ]
	    then
		OBPKG=1
	    fi
	    $PKGINFO -q VRTSobdev > /dev/null 2>&1
	    if [ $? = 0 ]
	    then
		OBDEVPKG=1
	    fi

	    VXSVC=$OBDIR/bin/vxsvc
	    if [ \( \( "$OBPKG" -eq 1 \) -o \( "$OBDEVPKG" -eq 1 \) \) -a \( -f $VXSVC \) ]
	    then
		[ "$verbose" = "yes" ] && message ""
	    else
		[ "$verbose" = "yes" ] && errmsg "This installation attempt detected that the
         VERITAS Enterprise Administrator Service package (VRTSob) is not installed on this host.

         You must first install the VERITAS Enterprise Administrator Service
         (VRTSob)package before installing this VM provider ($PKGNAME) package.

         This installation attempt of the VM provider package ($PKGNAME) will
         now be aborted.\n"
		fatalexit
	    fi
	    ##############
	    # VRTSob or VRTSobdev is installed, so continue with the VRTSvmpro
	    # package installation
	    ##############
	    ;;		

	AIX | aix)
	    SHLIB_EXT=so
	    #
	    # prerequisite packaging checks are done via the AIX packaging
	    # facilities	
	    #
	    OBDIR=/opt/VRTSob
	    VXSVC=$OBDIR/bin/vxsvc

	    ##############
	    # VRTSob is installed, so continue with VRTSvmprov pkg install
	    ##############
	    ;;		

	HP-UX | hpux)
	    SHLIB_EXT=sl
	    #
	    # prerequisite packaging checks are done via the HP packaging
	    # facilities	
	    #
	    OBDIR=/opt/VRTSob
	    VXSVC=$OBDIR/bin/vxsvc
	    ;;		

	Linux | linux)
	    SHLIB_EXT=so
	    #
	    # Perform checkinstall processing for the VERITAS Enterprise 
	    # Administrator Service package (VRTSob), and VERITAS Volume 
	    # Manager pkg (VRTSvxvm)
	    #
	    
	    # basedir of the VRTSob package
	    #
	    OBDIR=/opt/VRTSob

	    VXSVC=$OBDIR/bin/vxsvc
	    if [ -f $VXSVC ]
	    then
		[ "$verbose" = "yes" ] && message ""
	    else
		[ "$verbose" = "yes" ] && errmsg "This installation attempt detected that the VERITAS Enterprise Administrator
         Service package (VRTSob) is not installed on this host.

         You must first install the VERITAS Enterprise Administrator Service (VRTSob)
         package before installing this VM provider ($PKGNAME) package.

         This installation attempt of the VM provider package ($PKGNAME) will
         now be aborted.\n"
		fatalexit
	    fi

	    ##############
	    # VRTSob is installed, so continue with VRTSvmprov pkg install
	    ##############
	    ;;		

	esac	
    fi	# force = no


    #############################################
    # register the vmprovider to VIP 
    #############################################
if [ "$option" = "add" ]
then
    vmprov_register
fi   # add	



###################################
#
# remove VM provider config
#
###################################
if [ "$option" = "remove" ]
then
    set_echo

    # Perform preremove processing for the VRTSvmpro package.

    #
    # based on basedir of the VRTSob package
    #
    VXSVC=$OBDIR/bin/vxsvc

    #############################################
    # un-register the vmprovider to VIP 
    #############################################
    vmprov_unregister
 
fi   # remove

if [ "$option" = "patchadd" ]
then
    set_echo

    # Perform preremove processing for the VRTSvmpro package.
    #############################################
    # add patch the vmprovider to VIP 
    #############################################
    vmprov_patchadd
 
fi   # patchadd


if [ "$option" = "patchrm" ]
then
    set_echo

    #############################################
    # remove patch the vmprovider to VIP 
    #############################################
    vmprov_patchrm
 
fi   # patchrm


rm -f $TMPFILE

exit 0
